@@ -1,23 +1,19 @@
 package Yukki::Settings;
-$Yukki::Settings::VERSION = '0.991_007'; # TRIAL
-$Yukki::Settings::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
+BEGIN {
+  $Yukki::Settings::VERSION = '0.110880';
+}
+use 5.12.1;
+use Moose;
 
-use Types::Path::Tiny qw( Path );
-use Types::Standard qw( Str );
-use Yukki::Settings::Repository;
-use Yukki::Types qw( PrivilegesMap RepositoryMap YukkiSettingsAnonymous );
-
-use namespace::clean;
+use MooseX::Types::Path::Class;
+use Yukki::Types qw( RepositoryMap );
 
 # ABSTRACT: provides structure and validation to settings in yukki.conf
 
 
 has root => (
     is          => 'ro',
-    isa         => Path,
+    isa         => 'Path::Class::Dir',
     required    => 1,
     coerce      => 1,
     default     => '.',
@@ -26,7 +22,7 @@ has root => (
 
 has repository_path => (
     is          => 'ro',
-    isa         => Path,
+    isa         => 'Path::Class::Dir',
     required    => 1,
     coerce      => 1,
     default     => 'repositories',
@@ -35,7 +31,7 @@ has repository_path => (
 
 has user_path => (
     is          => 'ro',
-    isa         => Path,
+    isa         => 'Path::Class::Dir',
     required    => 1,
     coerce      => 1,
     default     => 'var/db/users',
@@ -44,7 +40,7 @@ has user_path => (
 
 has digest => (
     is          => 'ro',
-    isa         => Str,
+    isa         => 'Str',
     required    => 1,
     default     => 'SHA-512',
 );
@@ -52,22 +48,13 @@ has digest => (
 
 has anonymous => (
     is          => 'ro',
-    isa         => YukkiSettingsAnonymous,
+    isa         => 'Yukki::Settings::Anonymous',
     required    => 1,
     coerce      => 1,
     default     => sub { Yukki::Settings::Anonymous->new },
 );
 
 
-has repo_path => (
-    is          => 'ro',
-    isa         => Path,
-    required    => 1,
-    coerce      => 1,
-    default     => 'var/db/repos',
-);
-
-
 has repositories => (
     is          => 'ro',
     isa         => RepositoryMap,
@@ -77,52 +64,96 @@ has repositories => (
 
 {
     package Yukki::Settings::Anonymous;
-$Yukki::Settings::Anonymous::VERSION = '0.991_007'; # TRIAL
-$Yukki::Settings::Anonymous::VERSION = '0.991007';
-use Moo;
-    use Types::Standard qw( Str );
-    use Yukki::Types qw( EmailAddress );
+BEGIN {
+  $Yukki::Settings::Anonymous::VERSION = '0.110880';
+}
+    use Moose;
 
     has author_name => (
         is          => 'ro',
-        isa         => Str,
+        isa         => 'Str',
         required    => 1,
         default     => 'Anonymous',
     );
 
     has author_email => (
         is          => 'ro',
-        isa         => EmailAddress,
+        isa         => 'Email::Address',
         required    => 1,
         coerce      => 1,
         default     => 'anonymous@localhost',
     );
 }
 
+{
+    package Yukki::Settings::Repository;
+BEGIN {
+  $Yukki::Settings::Repository::VERSION = '0.110880';
+}
+    use Moose;
 
-has special_privileges => (
-    is          => 'ro',
-    isa         => PrivilegesMap,
-    required    => 1,
-    coerce      => 1,
-    default     => sub { +{} },
-);
+    has repository => (
+        is          => 'ro',
+        isa         => 'Path::Class::Dir',
+        required    => 1,
+        coerce      => 1,
+    );
+
+    has site_branch => (
+        is          => 'ro',
+        isa         => 'Str',
+        required    => 1,
+        default     => 'refs/heads/master',
+    );
+
+    has name => (
+        is          => 'ro',
+        isa         => 'Str',
+        required    => 1,
+    );
+
+    has default_page => (
+        is          => 'ro',
+        isa         => 'Path::Class::File',
+        required    => 1,
+        coerce      => 1,
+        default     => 'home.yukki',
+    );
+
+    has anonymous_access_level => (
+        is          => 'ro',
+        isa         => Yukki::Types::AccessLevel,
+        required    => 1,
+        default     => 'none',
+    );
+
+    has read_groups => (
+        is          => 'ro',
+        isa         => 'Str|ArrayRef[Str]',
+        required    => 1,
+        default     => 'NONE',
+    );
+
+    has write_groups => (
+        is          => 'ro',
+        isa         => 'Str|ArrayRef[Str]',
+        required    => 1,
+        default     => 'NONE',
+    );
+}
 
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Settings - provides structure and validation to settings in yukki.conf
 
 =head1 VERSION
 
-version 0.991_007
+version 0.110880
 
 =head1 DESCRIPTION
 
@@ -166,37 +197,45 @@ This is the email address to use when an anonymous user makes a change to a wiki
 
 =back
 
-=head2 repo_path
-
-This is the folder where repository configuraiton files can be found. This path is intended for application managed repository configuration files. If you want to manage your repositories from the command-line instead, store the repository configurations under the C<repository> key in the main settings file.
-
 =head2 repositories
 
 This is a section under which each repository is configured. The keys under here are the name found in the URL. It is also the name to use when running the F<yukki-git-init> and other repository-related commands.
 
-Repository configurations may be stored either in the main Yukki configuration file under the C<repositories> key or as individual files located in the directory named in the C<repo_path> key. If a configuration is named in both places, the one in the main settings file will always be used.
-
-Each repository configuration should provide the following configruation keys.
-
-=head2 special_privileges
-
-This section of the settings configures which groups grant special privileges. These special privileges grant access to view or change the configuration from within the application. By default, no one has these privileges, effectively disabling any in-app administrative features.
-
-The grants for each here are identical to that available to repositories:
+Each repository configuraiton should provide the following configruation keys.
 
 =over
 
+=item repository
+
+This is required. This is the name of the git repository folder found under C<repository_path>.
+
+=item site_branch
+
+This is teh name of the branch that will contain the wiki's files. The default is C<refs/heads/master>. You could actually use the same git repository for multiple Yukki repositories by using different branches. If you want to do it that way for some reason. Unless you know what you're doing, you probably don't want to do that.
+
+=item name
+
+This is a human readable title for the repository.
+
+=item default_page
+
+This is the name of the main repository index. 
+
 =item anonymous_access_level
 
-This names the access level anonymous users have. Obviously, it would generally be unwise for this to be anything but "none" for adminsitrative functions, but "read" and "write" are other possible values.
+This should be set to one of the following: read, write, or none. This settings decides how much access an anonymous user has when visiting your wiki.
 
 =item read_groups
 
-Names the list of groups that are granted permission to perform read-only actions. This may also be set to "ANY" to specify that any logged user may perform this action or "NONE" to specify that no logged user may perform this action.
+This may be set to the word "ANY" or the word "NONE" or to an array of group names.
+
+If set to ANY, any logged user may read this repository. If set to NONE, read access is not granted to any logged user (though if C<anonymous_access_level> or C<write_groups> grant a user access, the user will be able to read the repository).
+
+If an array of one or more group names are given, the users with any of those groups will be able to read the repository.
 
 =item write_groups
 
-Names the list of groups that are granted permission to perform read-write actions. As with read, this may be set to "ANY" and "NONE" with the same meaning.
+THe possible values that may be set are identicl to C<read_groups>. This setting determines who has permission to edit pages and upload files to the repository.
 
 =back
 
@@ -206,9 +245,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
